==> apache-cloudstack-4.18.2.3-src.tar.bz2: apache-cloudstack-4.18.2.3-src/plugins/network-elements/tungsten/src/test/java/org/apache/cloudstack/network/tungsten/api/command/DeleteTungstenFabricPolicyCmdTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.network.tungsten.api.command;

import org.apache.cloudstack.api.response.SuccessResponse;
import org.apache.cloudstack.network.tungsten.service.TungstenService;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.ArgumentMatchers;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;
import org.powermock.reflect.Whitebox;

@RunWith(PowerMockRunner.class)
@PrepareForTest(DeleteTungstenFabricPolicyCmd.class)
public class DeleteTungstenFabricPolicyCmdTest {

    @Mock
    TungstenService tungstenService;

    DeleteTungstenFabricPolicyCmd deleteTungstenFabricPolicyCmd;

    @Before
    public void setup() {
        MockitoAnnotations.initMocks(this);
        deleteTungstenFabricPolicyCmd = new DeleteTungstenFabricPolicyCmd();
        deleteTungstenFabricPolicyCmd.tungstenService = tungstenService;
        Whitebox.setInternalState(deleteTungstenFabricPolicyCmd, "zoneId", 1L);
        Whitebox.setInternalState(deleteTungstenFabricPolicyCmd, "policyUuid", "test");
    }

    @Test
    public void executeTest() throws Exception {
        SuccessResponse successResponse = Mockito.mock(SuccessResponse.class);
        Mockito.when(tungstenService.deleteTungstenPolicy(ArgumentMatchers.anyLong(),
                ArgumentMatchers.anyString())).thenReturn(true);
        PowerMockito.whenNew(SuccessResponse.class).withAnyArguments().thenReturn(successResponse);
        deleteTungstenFabricPolicyCmd.execute();
        Assert.assertEquals(successResponse, deleteTungstenFabricPolicyCmd.getResponseObject());
    }
}

==> apache-cloudstack-4.20.1.0-src.tar.bz2: apache-cloudstack-4.20.1.0-src/plugins/network-elements/tungsten/src/test/java/org/apache/cloudstack/network/tungsten/api/command/DeleteTungstenFabricPolicyCmdTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.network.tungsten.api.command;

import org.apache.cloudstack.api.response.SuccessResponse;
import org.apache.cloudstack.network.tungsten.service.TungstenService;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.ArgumentMatchers;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.test.util.ReflectionTestUtils;

@RunWith(MockitoJUnitRunner.class)
public class DeleteTungstenFabricPolicyCmdTest {

    @Mock
    TungstenService tungstenService;

    DeleteTungstenFabricPolicyCmd deleteTungstenFabricPolicyCmd;

    AutoCloseable closeable;

    @Before
    public void setup() {
        closeable = MockitoAnnotations.openMocks(this);
        deleteTungstenFabricPolicyCmd = new DeleteTungstenFabricPolicyCmd();
        deleteTungstenFabricPolicyCmd.tungstenService = tungstenService;
        ReflectionTestUtils.setField(deleteTungstenFabricPolicyCmd, "zoneId", 1L);
        ReflectionTestUtils.setField(deleteTungstenFabricPolicyCmd, "policyUuid", "test");
    }

    @After
    public void tearDown() throws Exception {
        closeable.close();
    }

    @Test
    public void executeTest() throws Exception {
        Mockito.when(tungstenService.deleteTungstenPolicy(ArgumentMatchers.anyLong(),
                ArgumentMatchers.anyString())).thenReturn(true);
        deleteTungstenFabricPolicyCmd.execute();
        Assert.assertTrue(((SuccessResponse) deleteTungstenFabricPolicyCmd.getResponseObject()).getSuccess());
    }
}
